==> nipper-0.10.4.tgz: nipper-0.10.4/PIX/report-debug.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by Ian Ventura-Whiting (Fizz)               *
 *   fizz@titania.co.uk                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


void reportPIXDebug(struct nipperConfig *nipper)
{
	// Variables
	struct johnPassword *johnPointer;
	struct interfacePIXConfig *interfacePIXPointer;
	struct accessListPIX *accessPointer;
	struct accessListPIXPermission *permissionPointer;
	struct objectGroupList *objectGroupPointer;
	struct objectList *objectPointer;
	struct namePIXList *namePIXPointer;
	struct enablePIXPassword *enablePIXPointer;
	struct usernamePIX *usernamePIXPointer;
	struct fixupList *fixupPIXPointer;
	struct icmpAccess *icmpPIXPointer;
	struct staticPIX *staticPIXPointer;
	struct routePIX *routePIXPointer;

	// Setting info
	printf("\n\nFor some debug settings...\n");
	printf("  True or Enabled = %d\n", true);
	printf("  False or Disabled = %d\n", false);
	printf("  Unconfigured = %d\n\n", unconfigured);

	// General Info
	printf("\n%sInformation Collected\n=====================%s\n", COL_BLUE, RESET);
	printf("Hostname: %s\n", nipper->hostname);
	printf("Domain Name: %s\n", nipper->domainName);
	printf("Version: %s\n", nipper->version);
	printf("Version: %d.%d(%d)\n", nipper->versionMajor, nipper->versionMinor, nipper->versionRevision);
	printf("Type: %d\n", nipper->deviceType);
	printf("Transparent: %d\n", nipper->pix->transparent);

	// Users and Passwords
	printf("Password: %s\n", nipper->pix->password);
	enablePIXPointer = nipper->pix->enable;
	while (enablePIXPointer != 0)
	{
		printf("Enable Password: %s\n", enablePIXPointer->passwordEncrypted);
		printf("  Enable Level: %d\n", enablePIXPointer->level);
		enablePIXPointer = enablePIXPointer->next;
	}
	usernamePIXPointer = nipper->pix->username;
	while (usernamePIXPointer != 0)
	{
		printf("Username: %s\n", usernamePIXPointer->username);
		printf("  Encrypted Password: %s\n", usernamePIXPointer->passwordEncrypted);
		printf("  Encryption: %d\n", usernamePIXPointer->encryption);
		printf("  Level: %d\n", usernamePIXPointer->level);
		usernamePIXPointer = usernamePIXPointer->next;
	}

	// SSH
	if (nipper->pix->ssh != 0)
	{
		printf("SSH Config:\n");
		printf("  SSH Version: %d\n", nipper->pix->ssh->version);
		printf("  Timeout: %d\n", nipper->pix->ssh->timeout);
		printf("  IP Address: %s\n", nipper->pix->ssh->ipAddress);
		printf("  Net Mask: %s\n", nipper->pix->ssh->netMask);
		printf("  Interface: %s\n", nipper->pix->ssh->interface);
	}

	// Interfaces
	interfacePIXPointer = nipper->pix->interface;
	while (interfacePIXPointer != 0)
	{
		printf("Interface: %s\n", interfacePIXPointer->interface);
		printf("  Name: %s\n", interfacePIXPointer->name);
		printf("  Shutdown: %d\n", interfacePIXPointer->shutdown);
		printf("  IP Address: %s\n", interfacePIXPointer->ipAddress);
		printf("  IP Mask: %s\n", interfacePIXPointer->netMask);
		printf("  Security: %d\n", interfacePIXPointer->security);
		printf("  Speed: %d\n", interfacePIXPointer->netSpeed);
		printf("  MTU: %d\n", interfacePIXPointer->mtu);
		printf("  In ACL: %s\n", interfacePIXPointer->in);
		printf("  In Override: %d\n", interfacePIXPointer->inOverride);
		printf("  Out ACL: %s\n", interfacePIXPointer->out);
		printf("  Out Override: %d\n", interfacePIXPointer->outOverride);
		interfacePIXPointer = interfacePIXPointer->next;
	}

	// Access Lists
	printf("Access List Alert Interval: %d\n", nipper->pix->accessListAlertInterval);
	printf("Access List Deny-Flow-Max: %d\n", nipper->pix->accessListDenyFlowMax);
	accessPointer = nipper->pix->access;
	while (accessPointer != 0)
	{
		printf("Access-List: %s\n", accessPointer->name);
		printf("  Remark: %s\n", accessPointer->remark);
		printf("  Type: %d\n", accessPointer->type);
		permissionPointer = accessPointer->permission;
		while (permissionPointer != 0)
		{
			printf("  Permission: %d\n", permissionPointer->permission);
			printf("    Protocol: %s\n", permissionPointer->protocol);
			printf("    Protocol Type: %d\n", permissionPointer->protocolType);
			printf("    Source: %s\n", permissionPointer->source);
			printf("    Source Mask: %s\n", permissionPointer->sourceMask);
			printf("    Source Type: %d\n", permissionPointer->sourceType);
			printf("    Source Service: %s\n", permissionPointer->sourceService);
			printf("    Source Service Operatior: %d\n", permissionPointer->sourceServiceOp);
			printf("    Destination: %s\n", permissionPointer->dest);
			printf("    Destination Mask: %s\n", permissionPointer->destMask);
			printf("    Destination Type: %d\n", permissionPointer->destType);
			printf("    Destination Service: %s\n", permissionPointer->destService);
			printf("    Destination Service Operatior: %d\n", permissionPointer->destServiceOp);
			printf("    Inactive: %d\n", permissionPointer->inactive);
			printf("    Time Range: %s\n", permissionPointer->timeRange);
			printf("    Log: %d\n", permissionPointer->log);
			permissionPointer = permissionPointer->next;
		}
		accessPointer = accessPointer->next;
	}

	// ICMP Access
	icmpPIXPointer = nipper->pix->icmp;
	while (icmpPIXPointer != 0)
	{
		printf("ICMP Access: %d\n", icmpPIXPointer->permission);
		printf("  Source: %s\n", icmpPIXPointer->source);
		printf("  Source Type: %d\n", icmpPIXPointer->sourceType);
		printf("  ICMP Type: %s\n", icmpPIXPointer->icmpType);
		printf("  Interface: %s\n", icmpPIXPointer->interface);
		icmpPIXPointer = icmpPIXPointer->next;
	}

	// Protocol Analysis
	fixupPIXPointer = nipper->pix->fixup;
	while (fixupPIXPointer != 0)
	{
		printf("Fixup Protocol: %s\n", fixupPIXPointer->protocol);
		printf("  Fixup Options: %s\n", fixupPIXPointer->options);
		printf("  Enabled: %d\n", fixupPIXPointer->enabled);
		fixupPIXPointer = fixupPIXPointer->next;
	}

	// Static NAT / PAT
	staticPIXPointer = nipper->pix->staticNAT;
	while (staticPIXPointer != 0)
	{
		printf("Static NAT Configuration\n");
		printf("  Real Interface: %s\n", staticPIXPointer->interfaceReal);
		printf("  Mapped Interface: %s\n", staticPIXPointer->interfaceMapped);
		printf("  Mapped IP: %s\n", staticPIXPointer->ipMapped);
		printf("  Real IP: %s\n", staticPIXPointer->ipReal);
		printf("  Real IP Mask: %s\n", staticPIXPointer->ipNetMaskReal);
		printf("  Access List: %s\n", staticPIXPointer->accessList);
		printf("  Interface: %d\n", staticPIXPointer->interface);
		printf("  DNS: %d\n", staticPIXPointer->dns);
		printf("  Nailed: %d\n", staticPIXPointer->nailed);
		printf("  Random Sequence Numbers: %d\n", staticPIXPointer->randomseq);
		printf("  Max TCP Connections: %d\n", staticPIXPointer->tcpMaxConnections);
		printf("  Max UDP Connections: %d\n", staticPIXPointer->udpMaxConnections);
		printf("  Max Embrionic Connections: %d\n", staticPIXPointer->embrionicConnections);
		staticPIXPointer = staticPIXPointer->next;
	}

	// Static Route
	routePIXPointer = nipper->pix->route;
	while (routePIXPointer != 0)
	{
		printf("Static Route\n");
		printf("  Interface: %s\n", routePIXPointer->interface);
		printf("  IP Address: %s\n", routePIXPointer->ipAddress);
		printf("  Net Mask: %s\n", routePIXPointer->netMask);
		printf("  Gateway: %s\n", routePIXPointer->gateway);
		printf("  Metric: %d\n", routePIXPointer->metric);
		printf("  Track: %d\n", routePIXPointer->track);
		printf("  Tunneled: %d\n", routePIXPointer->tunneled);
		routePIXPointer = routePIXPointer->next;
	}

	// Objects
	objectGroupPointer = nipper->pix->objectGroup;
	while (objectGroupPointer != 0)
	{
		printf("Object Group: %s\n", objectGroupPointer->name);
		printf("  Description: %s\n", objectGroupPointer->description);
		printf("  Group Type: %d\n", objectGroupPointer->type);
		printf("  Group Service Type: %d\n", objectGroupPointer->serviceType);
		objectPointer = objectGroupPointer->object;
		while (objectPointer != 0)
		{
			printf("  Object: %s\n", objectPointer->object);
			printf("    Net Mask: %s\n", objectPointer->netMask);
			printf("    Type: %d\n", objectPointer->type);
			objectPointer = objectPointer->next;
		}
		objectGroupPointer = objectGroupPointer->next;
	}

	// Name List
	namePIXPointer = nipper->pix->nameList;
	while (namePIXPointer != 0)
	{
		printf("IP Address: %s\n", namePIXPointer->address);
		printf("  Name: %s\n", namePIXPointer->name);
		namePIXPointer = namePIXPointer->next;
	}

	// John-the-ripper
	if (nipper->john != 0)
	{
		printf("\n%sJohn-the-ripper Output\n======================%s\n", COL_BLUE, RESET);
		johnPointer = nipper->john;
		while (johnPointer != 0)
		{
			printf("Username: %s\n", johnPointer->username);
			printf("  Password: %s\n", johnPointer->password);
			johnPointer = johnPointer->next;
		}
	}
}

==> nipper-0.10.5.tgz: nipper-0.10.5/PIX/report-debug.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by Ian Ventura-Whiting (Fizz)               *
 *   fizz@titania.co.uk                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


void reportPIXDebug(struct nipperConfig *nipper)
{
	// Variables
	struct johnPassword *johnPointer = 0;
	struct interfacePIXConfig *interfacePIXPointer = 0;
	struct accessListPIX *accessPointer = 0;
	struct accessListPIXPermission *permissionPointer = 0;
	struct objectGroupList *objectGroupPointer = 0;
	struct objectList *objectPointer = 0;
	struct namePIXList *namePIXPointer = 0;
	struct enablePIXPassword *enablePIXPointer = 0;
	struct usernamePIX *usernamePIXPointer = 0;
	struct fixupList *fixupPIXPointer = 0;
	struct icmpAccess *icmpPIXPointer = 0;
	struct staticPIX *staticPIXPointer = 0;
	struct routePIX *routePIXPointer = 0;

	// Setting info
	printf("\n\nFor some debug settings...\n");
	printf("  True or Enabled = %d\n", true);
	printf("  False or Disabled = %d\n", false);
	printf("  Unconfigured = %d\n\n", unconfigured);

	// General Info
	printf("\n%sInformation Collected\n=====================%s\n", COL_BLUE, RESET);
	printf("Hostname: %s\n", nipper->hostname);
	printf("Domain Name: %s\n", nipper->domainName);
	printf("Version: %s\n", nipper->version);
	printf("Version: %d.%d(%d)\n", nipper->versionMajor, nipper->versionMinor, nipper->versionRevision);
	printf("Type: %d\n", nipper->deviceType);
	printf("Transparent: %d\n", nipper->pix->transparent);

	// Users and Passwords
	printf("Password: %s\n", nipper->pix->password);
	enablePIXPointer = nipper->pix->enable;
	while (enablePIXPointer != 0)
	{
		printf("Enable Password: %s\n", enablePIXPointer->passwordEncrypted);
		printf("  Enable Level: %d\n", enablePIXPointer->level);
		enablePIXPointer = enablePIXPointer->next;
	}
	usernamePIXPointer = nipper->pix->username;
	while (usernamePIXPointer != 0)
	{
		printf("Username: %s\n", usernamePIXPointer->username);
		printf("  Encrypted Password: %s\n", usernamePIXPointer->passwordEncrypted);
		printf("  Encryption: %d\n", usernamePIXPointer->encryption);
		printf("  Level: %d\n", usernamePIXPointer->level);
		usernamePIXPointer = usernamePIXPointer->next;
	}

	// SSH
	if (nipper->pix->ssh != 0)
	{
		printf("SSH Config:\n");
		printf("  SSH Version: %d\n", nipper->pix->ssh->version);
		printf("  Timeout: %d\n", nipper->pix->ssh->timeout);
		printf("  IP Address: %s\n", nipper->pix->ssh->ipAddress);
		printf("  Net Mask: %s\n", nipper->pix->ssh->netMask);
		printf("  Interface: %s\n", nipper->pix->ssh->interface);
	}

	// Interfaces
	interfacePIXPointer = nipper->pix->interface;
	while (interfacePIXPointer != 0)
	{
		printf("Interface: %s\n", interfacePIXPointer->interface);
		printf("  Name: %s\n", interfacePIXPointer->name);
		printf("  Shutdown: %d\n", interfacePIXPointer->shutdown);
		printf("  IP Address: %s\n", interfacePIXPointer->ipAddress);
		printf("  IP Mask: %s\n", interfacePIXPointer->netMask);
		printf("  Security: %d\n", interfacePIXPointer->security);
		printf("  Speed: %d\n", interfacePIXPointer->netSpeed);
		printf("  MTU: %d\n", interfacePIXPointer->mtu);
		printf("  In ACL: %s\n", interfacePIXPointer->in);
		printf("  In Override: %d\n", interfacePIXPointer->inOverride);
		printf("  Out ACL: %s\n", interfacePIXPointer->out);
		printf("  Out Override: %d\n", interfacePIXPointer->outOverride);
		interfacePIXPointer = interfacePIXPointer->next;
	}

	// Access Lists
	printf("Access List Alert Interval: %d\n", nipper->pix->accessListAlertInterval);
	printf("Access List Deny-Flow-Max: %d\n", nipper->pix->accessListDenyFlowMax);
	accessPointer = nipper->pix->access;
	while (accessPointer != 0)
	{
		printf("Access-List: %s\n", accessPointer->name);
		printf("  Remark: %s\n", accessPointer->remark);
		printf("  Type: %d\n", accessPointer->type);
		permissionPointer = accessPointer->permission;
		while (permissionPointer != 0)
		{
			printf("  Permission: %d\n", permissionPointer->permission);
			printf("    Protocol: %s\n", permissionPointer->protocol);
			printf("    Protocol Type: %d\n", permissionPointer->protocolType);
			printf("    Source: %s\n", permissionPointer->source);
			printf("    Source Mask: %s\n", permissionPointer->sourceMask);
			printf("    Source Type: %d\n", permissionPointer->sourceType);
			printf("    Source Service: %s\n", permissionPointer->sourceService);
			printf("    Source Service Operatior: %d\n", permissionPointer->sourceServiceOp);
			printf("    Destination: %s\n", permissionPointer->dest);
			printf("    Destination Mask: %s\n", permissionPointer->destMask);
			printf("    Destination Type: %d\n", permissionPointer->destType);
			printf("    Destination Service: %s\n", permissionPointer->destService);
			printf("    Destination Service Operatior: %d\n", permissionPointer->destServiceOp);
			printf("    Inactive: %d\n", permissionPointer->inactive);
			printf("    Time Range: %s\n", permissionPointer->timeRange);
			printf("    Log: %d\n", permissionPointer->log);
			permissionPointer = permissionPointer->next;
		}
		accessPointer = accessPointer->next;
	}

	// ICMP Access
	icmpPIXPointer = nipper->pix->icmp;
	while (icmpPIXPointer != 0)
	{
		printf("ICMP Access: %d\n", icmpPIXPointer->permission);
		printf("  Source: %s\n", icmpPIXPointer->source);
		printf("  Source Type: %d\n", icmpPIXPointer->sourceType);
		printf("  ICMP Type: %s\n", icmpPIXPointer->icmpType);
		printf("  Interface: %s\n", icmpPIXPointer->interface);
		icmpPIXPointer = icmpPIXPointer->next;
	}

	// Protocol Analysis
	fixupPIXPointer = nipper->pix->fixup;
	while (fixupPIXPointer != 0)
	{
		printf("Fixup Protocol: %s\n", fixupPIXPointer->protocol);
		printf("  Fixup Options: %s\n", fixupPIXPointer->options);
		printf("  Enabled: %d\n", fixupPIXPointer->enabled);
		fixupPIXPointer = fixupPIXPointer->next;
	}

	// Static NAT / PAT
	staticPIXPointer = nipper->pix->staticNAT;
	while (staticPIXPointer != 0)
	{
		printf("Static NAT Configuration\n");
		printf("  Real Interface: %s\n", staticPIXPointer->interfaceReal);
		printf("  Mapped Interface: %s\n", staticPIXPointer->interfaceMapped);
		printf("  Mapped IP: %s\n", staticPIXPointer->ipMapped);
		printf("  Real IP: %s\n", staticPIXPointer->ipReal);
		printf("  Real IP Mask: %s\n", staticPIXPointer->ipNetMaskReal);
		printf("  Access List: %s\n", staticPIXPointer->accessList);
		printf("  Interface: %d\n", staticPIXPointer->interface);
		printf("  DNS: %d\n", staticPIXPointer->dns);
		printf("  Nailed: %d\n", staticPIXPointer->nailed);
		printf("  Random Sequence Numbers: %d\n", staticPIXPointer->randomseq);
		printf("  Max TCP Connections: %d\n", staticPIXPointer->tcpMaxConnections);
		printf("  Max UDP Connections: %d\n", staticPIXPointer->udpMaxConnections);
		printf("  Max Embrionic Connections: %d\n", staticPIXPointer->embrionicConnections);
		staticPIXPointer = staticPIXPointer->next;
	}

	// Static Route
	routePIXPointer = nipper->pix->route;
	while (routePIXPointer != 0)
	{
		printf("Static Route\n");
		printf("  Interface: %s\n", routePIXPointer->interface);
		printf("  IP Address: %s\n", routePIXPointer->ipAddress);
		printf("  Net Mask: %s\n", routePIXPointer->netMask);
		printf("  Gateway: %s\n", routePIXPointer->gateway);
		printf("  Metric: %d\n", routePIXPointer->metric);
		printf("  Track: %d\n", routePIXPointer->track);
		printf("  Tunneled: %d\n", routePIXPointer->tunneled);
		routePIXPointer = routePIXPointer->next;
	}

	// Objects
	objectGroupPointer = nipper->pix->objectGroup;
	while (objectGroupPointer != 0)
	{
		printf("Object Group: %s\n", objectGroupPointer->name);
		printf("  Description: %s\n", objectGroupPointer->description);
		printf("  Group Type: %d\n", objectGroupPointer->type);
		printf("  Group Service Type: %d\n", objectGroupPointer->serviceType);
		objectPointer = objectGroupPointer->object;
		while (objectPointer != 0)
		{
			printf("  Object: %s\n", objectPointer->object);
			printf("    Net Mask: %s\n", objectPointer->netMask);
			printf("    Type: %d\n", objectPointer->type);
			objectPointer = objectPointer->next;
		}
		objectGroupPointer = objectGroupPointer->next;
	}

	// Name List
	namePIXPointer = nipper->pix->nameList;
	while (namePIXPointer != 0)
	{
		printf("IP Address: %s\n", namePIXPointer->address);
		printf("  Name: %s\n", namePIXPointer->name);
		namePIXPointer = namePIXPointer->next;
	}

	// John-the-ripper
	if (nipper->john != 0)
	{
		printf("\n%sJohn-the-ripper Output\n======================%s\n", COL_BLUE, RESET);
		johnPointer = nipper->john;
		while (johnPointer != 0)
		{
			printf("Username: %s\n", johnPointer->username);
			printf("  Password: %s\n", johnPointer->password);
			johnPointer = johnPointer->next;
		}
	}
}
